[pypy-svn] r68347 - in pypy/branch/inline-fastpath-malloc/pypy/rpython: . lltypesystem

fijal at codespeak.net fijal at codespeak.net
Mon Oct 12 18:06:29 CEST 2009


Author: fijal
Date: Mon Oct 12 18:06:28 2009
New Revision: 68347

Modified:
   pypy/branch/inline-fastpath-malloc/pypy/rpython/llinterp.py
   pypy/branch/inline-fastpath-malloc/pypy/rpython/lltypesystem/lloperation.py
Log:
adjust names of operations, once again, so they're consistent with
generation's gc fields


Modified: pypy/branch/inline-fastpath-malloc/pypy/rpython/llinterp.py
==============================================================================
--- pypy/branch/inline-fastpath-malloc/pypy/rpython/llinterp.py	(original)
+++ pypy/branch/inline-fastpath-malloc/pypy/rpython/llinterp.py	Mon Oct 12 18:06:28 2009
@@ -848,10 +848,10 @@
     def op_gc_restore_exception(self, exc):
         raise NotImplementedError("gc_restore_exception")
 
-    def op_gc_adr_of_nursery_end(self):
+    def op_gc_adr_of_nursery_top(self):
         raise NotImplementedError
 
-    def op_gc_adr_of_nursery_pointer(self):
+    def op_gc_adr_of_nursery_free(self):
         raise NotImplementedError
 
     def op_gc_call_rtti_destructor(self, rtti, addr):

Modified: pypy/branch/inline-fastpath-malloc/pypy/rpython/lltypesystem/lloperation.py
==============================================================================
--- pypy/branch/inline-fastpath-malloc/pypy/rpython/lltypesystem/lloperation.py	(original)
+++ pypy/branch/inline-fastpath-malloc/pypy/rpython/lltypesystem/lloperation.py	Mon Oct 12 18:06:28 2009
@@ -442,9 +442,9 @@
 
     # ------- JIT & GC interaction, only for some GCs ----------
     
-    'gc_adr_of_nursery_pointer' : LLOp(),
-    # ^^^ returns an address of nursery pointer, for later modifications
-    'gc_adr_of_nursery_end' : LLOp(),
+    'gc_adr_of_nursery_free' : LLOp(),
+    # ^^^ returns an address of nursery free pointer, for later modifications
+    'gc_adr_of_nursery_top' : LLOp(),
     # ^^^ returns an address of pointer, since it can change at runtime
     
     # experimental operations in support of thread cloning, only



More information about the Pypy-commit mailing list